(multi-params-matcher schema)If only one parameter is provided to multi param, ring doesn't wrap the param is collection.
If only one parameter is provided to multi param, ring doesn't wrap the param is collection.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |