ring.swagger.common


deep-mergeclj

(deep-merge values)
(deep-merge strategy & values)

Recursively merges maps. If the first parameter is a keyword it tells the strategy to use when merging non-map collections. Options are

  • :replace, the default, the last value is used
  • :into, if the value in every map is a collection they are concatenated using into. Thus the type of (first) value is maintained.
Recursively merges maps.
If the first parameter is a keyword it tells the strategy to
use when merging non-map collections. Options are
- :replace, the default, the last value is used
- :into, if the value in every map is a collection they are concatenated
  using into. Thus the type of (first) value is maintained.
sourceraw docstring

extract-parametersclj

(extract-parameters c)

Extract parameters from head of the list. Parameters can be:

  1. a map (if followed by any form) [{:a 1 :b 2} :body] => {:a 1 :b 2}
  2. list of keywords & values [:a 1 :b 2 :body] => {:a 1 :b 2}
  3. else => {}

Returns a tuple with parameters and body without the parameters

Extract parameters from head of the list. Parameters can be:

1. a map (if followed by any form) `[{:a 1 :b 2} :body]` => `{:a 1 :b 2}`
2. list of keywords & values `[:a 1 :b 2 :body]` => `{:a 1 :b 2}`
3. else => `{}`

Returns a tuple with parameters and body without the parameters
sourceraw docstring

java-invokeclj

(java-invoke class-name method-name object)

Invokes a Java object method via reflection

Invokes a Java object method via reflection 
sourceraw docstring

java-invoke-firstclj

(java-invoke-first class-names method-name object)

Tries to invoke a method on the object using the first class name that can be resolved and is compatible with the given object. Useful when the same interface exists under multiple package names (e.g. javax.servlet vs jakarta.servlet).

Tries to invoke a method on the object using the first class name that
can be resolved and is compatible with the given object. Useful when the
same interface exists under multiple package names (e.g. javax.servlet
vs jakarta.servlet).
sourceraw docstring

plain-map?clj

(plain-map? x)

checks whether input is a map, but not a record

checks whether input is a map, but not a record
sourceraw docstring

record-schemaclj

(record-schema x)
source

remove-empty-keysclj

(remove-empty-keys m)

Removes empty properties with nil value from a map

Removes empty properties with nil value from a map
sourceraw docstring

titleclj

(title x)
source

titledclj

(titled x)
source

update-in-or-remove-keyclj

(update-in-or-remove-key m ks f)
(update-in-or-remove-key m ks f iff)
source

value-ofclj

(value-of x)

Extracts value of for var, symbol or returns itself

Extracts value of for var, symbol or returns itself
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries