(deep-merge values)(deep-merge strategy & values)Recursively merges maps. If the first parameter is a keyword it tells the strategy to use when merging non-map collections. Options are
Recursively merges maps. If the first parameter is a keyword it tells the strategy to use when merging non-map collections. Options are - :replace, the default, the last value is used - :into, if the value in every map is a collection they are concatenated using into. Thus the type of (first) value is maintained.
(extract-parameters c)Extract parameters from head of the list. Parameters can be:
[{:a 1 :b 2} :body] => {:a 1 :b 2}[:a 1 :b 2 :body] => {:a 1 :b 2}{}Returns a tuple with parameters and body without the parameters
Extract parameters from head of the list. Parameters can be:
1. a map (if followed by any form) `[{:a 1 :b 2} :body]` => `{:a 1 :b 2}`
2. list of keywords & values `[:a 1 :b 2 :body]` => `{:a 1 :b 2}`
3. else => `{}`
Returns a tuple with parameters and body without the parameters(java-invoke class-name method-name object)Invokes a Java object method via reflection
Invokes a Java object method via reflection
(java-invoke-first class-names method-name object)Tries to invoke a method on the object using the first class name that can be resolved and is compatible with the given object. Useful when the same interface exists under multiple package names (e.g. javax.servlet vs jakarta.servlet).
Tries to invoke a method on the object using the first class name that can be resolved and is compatible with the given object. Useful when the same interface exists under multiple package names (e.g. javax.servlet vs jakarta.servlet).
(plain-map? x)checks whether input is a map, but not a record
checks whether input is a map, but not a record
(remove-empty-keys m)Removes empty properties with nil value from a map
Removes empty properties with nil value from a map
(update-in-or-remove-key m ks f)(update-in-or-remove-key m ks f iff)(value-of x)Extracts value of for var, symbol or returns itself
Extracts value of for var, symbol or returns itself
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |